/*
 * (c) Copyright IBM Corp. 2000, 2002.
 * All Rights Reserved.
 */
package org.eclipse.tomcat.internal;
import java.io.IOException;
import java.net.*;

import org.apache.catalina.net.ServerSocketFactory;
public class PortTrackingServerSocketFactory implements ServerSocketFactory {
	private int assignedPort;
	public ServerSocket createSocket(int port)
		throws IOException {
		ServerSocket socket = new ServerSocket(port);
		listen(socket);
		assignedPort = socket.getLocalPort();
		return socket;
	}
	public ServerSocket createSocket(int port, int backlog)
		throws java.io.IOException {
		ServerSocket socket = new ServerSocket(port, backlog);
		listen(socket);
		assignedPort = socket.getLocalPort();
		return socket;
	}
	public ServerSocket createSocket(
		int port,
		int backlog,
		java.net.InetAddress ifAddress)
		throws java.io.IOException {
		ServerSocket socket = new ServerSocket(port, backlog, ifAddress);
		listen(socket);
		assignedPort = socket.getLocalPort();
		return socket;
	}
	/**
	 * Obtains port assigned to the last server socket created.
	 * @return Returns a int
	 */
	public int getAssignedPort() {
		return assignedPort;
	}
	/**
	 * Workaround for the absence of
	 * a listen() method on server socket.
	 */
	private void listen(ServerSocket ssocket) {
		try {
			ssocket.setSoTimeout(1);
			try {
				ssocket.accept();
			} catch (IOException exc) {
			}
			ssocket.setSoTimeout(0);
		} catch (SocketException sockEx) {
		}
	}
}